<?php
// $Id: openadstream.admin.inc,v 1.1 2009/12/04 03:20:47 damienmckenna Exp $
/**
 * @file
 * Settings pages for Open AdStream.
 */

function openadstream_admin_settings() {
  $form = array();
  
  $form['openadstream_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General Settings'),
    '#weight' => -10,
    '#collapsible' => false,
    '#collapsed' => false,
    '#description' => t("These settings should be provided by 24/7 RealMedia."),
  );

  $form['openadstream_settings']['openadserver_oas_hostname'] = array(
    '#type' => 'textfield',
    '#title' => t('OAS Hostname'),
    '#default_value' => variable_get('openadserver_oas_hostname', 'oasc03049.247realmedia.com'),
    '#size' => 50,
    '#maxlength' => 100,
    '#weight' => 0,
    '#description' => 'The hostname used to request ads, the default should be sufficient.',
  );

  $form['openadstream_settings']['openadstream_hostname'] = array(
    '#type' => 'textfield',
    '#title' => t('Hostname'),
    '#default_value' => variable_get('openadstream_hostname', ''),
    '#size' => 50,
    '#maxlength' => 100,
    '#weight' => 0,
    '#description' => 'By default, we will be using the current hostname',
  );
  
  $form['openadstream_settings']['openadstream_pagename'] = array(
    '#type' => 'textfield',
    '#title' => t('Page Name'),
    '#default_value' => variable_get('openadstream_pagename', ''),
    '#size' => 50,
    '#maxlength' => 50,
    '#weight' => 1,
    '#description' => 'This should only be used for testing',
  );
  
  return system_settings_form($form);
}

function openadstream_admin_positions() {
  $positions = _openadstream_admin_positions();
  $default_positions = _openadstream_invoke_default_positions();
  
  $header = array(
    t('Position Name'), 
    t('Operations')
  );
  
  $rows = array();
  foreach ($positions as $position) {
    $rows[] = array(
      $position['name'],
      l('delete', 'admin/settings/openadstream/positions-delete/'. $position['position_id']),
    );
  }
  
  $default_rows = array();
  foreach ($default_positions as $position) {
    $default_rows[] = array(
      $position['name'],
      '',
    );
  }
  
  $output .= "<h3>Existing Positions</h3>\n";
  $output .= theme('table', $header, $rows);
  $output .= "<br />\n";
  $output .= "<h3>Default Positions</h3>\n";
  $output .= theme('table', $header, $default_rows);
  return $output;
}

function openadstream_admin_positions_add() {
  $form = array();
  
  $form['position'] = array(
    '#type' => 'fieldset',
    '#title' => t('Position Settings'),
    '#collapsible' => false,
    '#collapsed' => false,
  );
  
  $form['position']['position_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Position Name'),
    '#description' => t('The position name is set in the OAS management interface.  24/7 RealMedia will provide this value'),
    '#size' => 30,
    '#maxlength' => 75,
    '#required' => true,
  );
    
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );
  
  return $form;
}

function openadstream_admin_positions_add_validate($form, &$form_state) {
  $values = $form_state['values'];
  
  if (db_result(db_query("SELECT COUNT(*) FROM {openadstream_positions} WHERE name = '%s'", $values['position_name']))) {
    form_set_error('info', t('The position name %name is already in use', array('%name' => $values['position_name'])));
  }
}

function openadstream_admin_positions_add_submit($form, &$form_state) {
  $values = $form_state['values'];
  db_query("INSERT INTO {openadstream_positions} (name) VALUES ('%s')", $values['position_name']);
  _openadstream_clear_positions_cache();
  drupal_set_message(t('The position %name has been created', array('%name' => $values['position_name'])));
  drupal_goto('admin/settings/openadstream/positions');
}

function openadstream_admin_positions_delete(&$form_state, $position_id) {
  $position = db_fetch_object(db_query("SELECT * FROM {openadstream_positions} WHERE position_id = %d", $position_id));
  
  drupal_set_title(t("Position '@name'", array('@name' => $position->name)));
  
  $form = array(
    'position_id' => array(
      '#type' => 'value',
      '#value' => $position_id,
    ),
  );
  
  return confirm_form($form,
    t("Are you sure you want to delete position '%name'?", array('%name' => $position->name)),
    'admin/settings/openadstream/positions',
    t('This action cannot be undone'),
    t('Delete'), t('Cancel')
  );
}

function openadstream_admin_positions_delete_submit($formid, &$form_state) {
  if ($form_state['values']['confirm']) {
    db_query("DELETE FROM {openadstream_positions} WHERE position_id = %d", $form_state['values']['position_id']);
    _openadstream_clear_positions_cache();
    drupal_set_message(t('The position has been deleted'));
  }
  $form_state['redirect'] = 'admin/settings/openadstream/positions';
  _block_rehash();
}

function openadstream_admin_pagenames() {
  $pagenames = _openadstream_admin_pagenames();
  $default_pagenames = _openadstream_invoke_default_pagenames();

  $form = array();
  $form['pagenames'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pagenames'),
    '#collapsible' => false,
    '#collapsed' => false,
    '#description' => "Override the Open AdStream pagename variable based on
      the page path. A pagename with path &lt;front&gt; will replace the
      pagename on the home page. The '*' character can be used as a wildcard.
      The path blog/* matches all pages under blog/.<br />
      Pagenamess are checked by weight from lowest to highest. The first entry
      that matches the current path is used.",
  );
  
  $header = array(
    t('Pagename'), 
    t('Weight'),
    t('Path'),
    t('Operations'),
  );
  
  $rows = array();
  foreach ($pagenames as $pagename) {
    $edit_link = l('edit', 'admin/settings/openadstream/pagenames-edit/'. $pagename['pagename_id']);
    $delete_link = l('delete', 'admin/settings/openadstream/pagenames-delete/'. $pagename['pagename_id']);
    
    $rows[] = array(
      $pagename['pagename'],
      $pagename['weight'],
      htmlspecialchars($pagename['path']),
      $edit_link .' | '. $delete_link,
    );
  }
  
  $default_rows = array();
  foreach ($default_pagenames as $pagename) {
    $default_rows[] = array(
      $pagename['pagename'],
      $pagename['weight'],
      htmlspecialchars($pagename['path']),
      '',
    );
  }
  
  $output = drupal_render_form('openadstream_pagenames', $form);
  $output .= "<h3>Existing Pagenames</h3>\n";
  $output .= theme('table', $header, $rows);
  $output .= "<br />\n";
  $output .= "<h3>Default Pagenames</h3>\n";
  $output .= theme('table', $header, $default_rows);
  return $output;
}

function openadstream_admin_pagenames_add() {
  $form = array();
  
  $form['pagename'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pagename Settings'),
    '#collapsible' => false,
    '#collapsed' => false,
  );
  
  $form['pagename']['pagename'] = array(
    '#type' => 'textfield',
    '#title' => t('Pagename'),
    '#description' => t('The pagename will be overridden with this value when viewing a page with the specified path.'),
    '#size' => 30,
    '#maxlength' => 75,
    '#required' => true,
  );
  
  $form['pagename']['weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight'),
    '#description' => t('Pagenames are applied by order of weight. If a path matches multiple pagename entries then the entry with the highest weight wins.'),
    '#default_value' => 0,
    '#size' => 5,
    '#maxlength' => 5,
    '#required' => true,
  );
  
  $form['pagename']['path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path'),
    '#description' => t("Enter a drupal path. The '*' character is a wildcard. Example paths are blog for the blog page and blog/* for every personal blog. &lt;front&gt; is the front page."),
    '#size' => 30,
    '#maxlength' => 255,
    '#required' => true,
  );
    
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );
  
  return $form;
}

function openadstream_admin_pagenames_edit(&$form_state, $pagename_id) {
  $pagename = db_fetch_object(db_query("SELECT * FROM {openadstream_pagenames} WHERE pagename_id = %d", $pagename_id));
  
  $form = array();
  
  $form['pagename'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pagename Settings'),
    '#collapsible' => false,
    '#collapsed' => false,
  );
  
  $form['pagename']['pagename'] = array(
    '#type' => 'textfield',
    '#title' => t('Pagename'),
    '#description' => t('The pagename will be overridden with this value when viewing a page with the specified path.'),
    '#size' => 30,
    '#maxlength' => 75,
    '#required' => true,
    '#default_value' => $pagename->pagename,
  );
  
  $form['pagename']['weight'] = array(
    '#type' => 'textfield',
    '#title' => t('Weight'),
    '#description' => t('Pagenames are applied by order of weight. If a path matches multiple pagename entries then the entry with the highest weight wins.'),
    '#default_value' => $pagename->weight,
    '#size' => 5,
    '#maxlength' => 5,
    '#required' => true,
  );
  
  $form['pagename']['path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path'),
    '#description' => t("Enter a drupal path. The '*' character is a wildcard. Example paths are blog for the blog page and blog/* for every personal blog. &lt;front&gt; is the front page."),
    '#size' => 30,
    '#maxlength' => 255,
    '#required' => true,
    '#default_value' => $pagename->path,
  );
  
  $form['pagename']['pagename_id'] = array(
    '#type' => 'value',
    '#value' => $pagename->pagename_id,
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );
  
  return $form;
}

function openadstream_admin_pagenames_edit_submit($form, &$form_state) {
  $values = $form_state['values'];
  $sql = "UPDATE {openadstream_pagenames} SET pagename = '%s', weight = %d, path = '%s' WHERE pagename_id = %d";
  db_query($sql, $values['pagename'], $values['weight'], $values['path'], $values['pagename_id']);
  _openadstream_clear_pagenames_cache();
  drupal_set_message('Pagename pagename has been updated');
  drupal_goto('admin/settings/openadstream/pagenames');
}

function openadstream_admin_pagenames_add_submit($form, &$form_state) {
  $values = $form_state['values'];
  $sql = "INSERT INTO {openadstream_pagenames} (pagename, weight, path) VALUES ('%s', %d, '%s')";
  db_query($sql, $values['pagename'], $values['weight'], $values['path']);
  _openadstream_clear_pagenames_cache();
  drupal_set_message(t('The pagename pagename %name has been created', array('%name' => $values['pagename'])));
  drupal_goto('admin/settings/openadstream/pagenames');
}

function openadstream_admin_pagenames_delete(&$form_state, $pagename_id) {
  $pagename = db_fetch_object(db_query("SELECT * FROM {openadstream_pagenames} WHERE pagename_id = %d", $pagename_id));
  
  drupal_set_title(t("Pagename '@name'", array('@name' => $pagename->pagename)));
  
  $form = array(
    'pagename_id' => array(
      '#type' => 'value',
      '#value' => $pagename_id,
    ),
  );
  
  return confirm_form($form,
    t("Are you sure you want to delete pagename '%name'?", array('%name' => $pagename->pagename)),
    'admin/settings/openadstream/pagenames',
    t('This action cannot be undone'),
    t('Delete'), t('Cancel')
  );
}

function openadstream_admin_pagenames_delete_submit($formid, &$form_state) {
  if ($form_state['values']['confirm']) {
    db_query("DELETE FROM {openadstream_pagenames} WHERE pagename_id = %d", $form_state['values']['pagename_id']);
    _openadstream_clear_pagenames_cache();
    drupal_set_message(t('The pagename has been deleted'));
  }
  $form_state['redirect'] = 'admin/settings/openadstream/pagenames';
}
